![logo](https://raw.githubusercontent.com/LeanderGangso/pyMyShareSDK/master/.github/images/MyShare_sdk.png)

**Important!  
We do not have access to the API at this point, as the API itself is not yet launched.  
We will be working on and updatinging this repo as soon as the situation changes!**

We are making the MyShare API easy to use, through our MySDK.  
Let us deal with setting up the correct HTTP request, so you don't have to.

[![MyShare](https://img.shields.io/badge/MyShare-white?logo=data:image/svg%2bxml;base64, )](#pyMySharesdk)
[![Open source](https://img.shields.io/badge/Open_Source-white?logo=GitHub-Sponsors&logoColor=red)](#pyMySharesdk)
[![License](https://img.shields.io/pypi/l/pymysharesdk.svg?label=License&logo=license&logoColor=red&labelColor=white)](#edit-me)  
[![Python versions](https://img.shields.io/pypi/pyversions/pymysharesdk.svg?label=Python&logo=python&labelColor=white)](https://pypi.org/project/pymysharesdk/)
[![PyPi](https://img.shields.io/pypi/v/pymysharesdk.svg?logo=pypi&label=PyPi&labelColor=white)](https://pypi.org/project/pymysharesdk/)
[![Downloads](https://img.shields.io/pypi/dm/pymysharesdk?labelColor=white&logo=pypi&label=Downloads)](https://pypistats.org/packages/pymysharesdk)  
[![Build Status](https://travis-ci.com/LeanderGangso/pyMyShareSDK.svg?branch=master)](https://travis-ci.com/LeanderGangso/pyMyShareSDK)
[![Docs](https://img.shields.io/badge/docs-latest-8ab98b.svg)](https://github.com/LeanderGangso/pyMyShareSDK/wiki)  

## Table on contents

- [Introduction](#introduction)

- [Documentation](#documentation)

- [Getting help](#getting-help)

- [Contributing](#contributing)

<!-- - [License](#license---key-points) -->

- [API support](#api-support)

## Introduction

This library provides a pure Python interface for the MyShare API. MySDK supports all of the mentioned Python versions in the tag above.

Along with the initial API implementation, this library contains clever solutions to help you write even less code and easily combine multiple functions together.

> You will need a TOKEN from MyShare API in order for this library to function.

## Documentation

- Thake a look at our [Wiki pages](https://github.com/LeanderGangso/pyMyShareSDK/wiki/installation), here you will find all you need to start integrating MySDK into your project.

- Visit the [MyShare API](https://api.myshare.today) documentation, as each method is structured in the same way.  

> All our methods have the same name's as the API, but with **snake_casing** instead.  
  E.g. updateJob = update_job

## Getting help

You can get help in the following ways:

- We have a [telegram group](https://t.me/pyMyShareSDK) that you can join and ask any questions.

- Report bugs, request features or ask questions by [creatin an issue](https://github.com/LeanderGangso/pyMyShareSDK/issues/new/choose) or [a discussion](https://github.com/LeanderGangso/pyMyShareSDK/discussions/new).

- Our [Wiki pages](https://github.com/LeanderGangso/pyMyShareSDK/wiki) has the information you need.  

> You could always help us improve by adding missing information to the wiki! :)

## Contributing

Contributions of all sizes are welcome. Please review our [contribution guidelines](https://github.com/LeanderGangso/pyMyShareSDK/blob/master/CODE_OF_CONDUCT.md) to get started. You can also help by [reporting bugs](https://github.com/LeanderGangso/pyMyShareSDK/issues/new/choose) or making a pull request. Learn more about [pull requests](https://www.freecodecamp.org/news/how-to-make-your-first-pull-request-on-github-3/).

<!--
## License - key points

To be determined...

- When distributing derived works, the source code of the work must be made available under the same license.
- All modification's has to have the same license and be open source.
- You do not need to release you modified code, but we would really apreacheate it you did do a [pull request](https://www.freecodecamp.org/news/how-to-make-your-first-pull-request-on-github-3/) with you changes.

Disclaimer: I am not a lawyer, so any and all information given is strictly based on my understanding and may or may not be correct.
-->

## API support

⏳ [MyShare API 1.0](#link-to-release-notes)
<!--
- ✔  [MyShare API ...](#link-to-release-notes)
- ❌ [MyShare API ...](#link-to-release-notes)
